@@ -26,7 +26,6 @@ class PyHtmlGui:
                  view_class       : typing.Type[PyHtmlView],
                  static_dir       : str             = None,
                  template_dir     : str             = None,
-                 electron_app_dir : str             = None,
                  base_template    : str             = "pyHtmlGuiBase.html",
                  on_view_connected: typing.Callable = None,
                  on_view_disconnected: typing.Callable = None,
@@ -44,8 +43,6 @@ class PyHtmlGui:
         :param view_class: A class that Inherits from PyHtmlView
         :param static_dir: Static files, css, img go here
         :param template_dir: main.html and other html goes here
-        :param electron_app_dir: in case we use electron, this is the electron.js file we launch,
-                                 default file is in pyHtmlGui/assets/electron/main.py
         :param base_template: pyHtmlGuiBase in pyHtmlGui/assets/templates, or custom file in app templates dir
         :param size: window size
         :param on_view_connected: callback is called when a frontend connects via websocket,
@@ -74,43 +71,32 @@ class PyHtmlGui:
             size     = size,
             position = position,
         )
-        self.static_dir = None if static_dir is None else os.path.abspath(static_dir)
-        self.template_dir = None if template_dir is None else os.path.abspath(template_dir)
-        self.electron_app_dir = electron_app_dir
+
         if shared_secret == "":
             self.shared_secret = "%s" % uuid.uuid4()
         elif shared_secret is None:
             self.shared_secret = None
         else:
             self.shared_secret = shared_secret
+
         self.listen_host = listen_host
         self.listen_port = listen_port
         self.auto_reload = auto_reload
 
+        self.static_dir = None if static_dir is None else os.path.abspath(static_dir)
+        self.template_dir = None if template_dir is None else os.path.abspath(template_dir)
+
         if getattr(sys, 'frozen', False) is True:
             # noinspection PyUnresolvedReferences,PyProtectedMember
-            lib_dir = os.path.join(sys._MEIPASS, "pyhtmlgui")
+            self._internal_template_dir = os.path.join(sys._MEIPASS, "pyhtmlgui", "assets", "templates")
             self.auto_reload = False
         else:
-            lib_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)))
-
+            self._internal_template_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "assets", "templates")
         if self.template_dir is not None and not os.path.exists(self.template_dir):
             raise Exception("Template dir '%s' not found" % self.template_dir)
         if self.static_dir is not None and not os.path.exists(self.static_dir):
             raise Exception("Static dir '%s' not found" % self.static_dir)
 
-        self._internal_electron_dir = os.path.join(lib_dir, "assets", "electron")
-        if self.electron_app_dir is None:  # use default internal app
-            self.electron_app_dir = self._internal_electron_dir
-        else:
-            if getattr(sys, 'frozen', False) is not True:
-                # if we are not frozen, copy our internal lib to the electron target dir if it does not exist
-                for f in ["pyhtmlgui.js", "main.js", "package.json"]:
-                    lib_js_target = os.path.join(self.electron_app_dir, f)
-                    if not os.path.exists(lib_js_target):
-                        shutil.copyfile(os.path.join(self._internal_electron_dir, f), lib_js_target)
-
-        self._internal_template_dir = os.path.join(lib_dir, "assets", "templates")
         self.template_loader = jinja2.FileSystemLoader(searchpath=[self._internal_template_dir] if self.template_dir is None else [self._internal_template_dir, self.template_dir])
         self._template_env = jinja2.Environment(loader=self.template_loader, autoescape=jinja2.select_autoescape())
 
@@ -125,7 +111,6 @@ class PyHtmlGui:
         if self.static_dir is not None:
             self.flaskApp.route("/static/<path:path>")(self._static)
         self.flaskWebsocket.route("/ws")(self._websocket)
-        #self.flaskWebsocket.route("/ws/<endpoint>")(self._websocket)
         self.flaskWebsocket.init_app(self.flaskApp)
 
         self._server = WebsocketServerThread(self.flaskApp, self.listen_host, self.listen_port)
