@@ -125,8 +125,7 @@ class PyHtmlGuiInstance:
                         self._view.on_frontend_ready(len(self._websocket_connections))
 
                 elif message['name'] == "ping":
-                    pass
-
+                    return_val = None
                 else:
                     return_val = None
                     print("unknown python function", message['name'])
@@ -278,7 +277,7 @@ class WebsocketConnection:
         self.javascript_call_result_queues = {}
         self.javascript_call_result_objects = {}
         self.active = True
-        self.send_queue = queue.Queue()
+        self.send_queue = queue.Queue(maxsize=1000)
         self._send_t = threading.Thread(target=self._send_loop, daemon=True)
         self._send_t.start()
 
